<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

// Route::middleware('auth:api')->get('/user', function (Request $request) {
//     return $request->user();
// });

//Hpme Page route
Route::post('app-setting/home-page','Api\AppSetting\HomePageController@getHomePageData');

//Dynamic Menu route
Route::post('app-setting/menu','Api\AppSetting\MenuController@getAllMenu');

//Collection list from shopify
Route::post('app-setting/collection/list','Api\AppSetting\CollectionController@getAllCollection');
Route::post('app-setting/collection/product-by-collection','Api\AppSetting\CollectionController@getCollectionProduct');

//Search product and collection
Route::post('search/product','Api\Search\SearchController@searchProduct');
Route::get('getCollections','Api\Search\SearchController@getCollections');

//Product Variants
Route::post('app-setting/product/variants','Api\AppSetting\VariantsController@getProductVariants');

//Category Faq
Route::post('app-setting/category/faq','Api\AppSetting\CategoryController@getCategoryDetail');

//Contact us
Route::post('app-setting/contact/sendmail','Api\AppSetting\ContactUsController@sendMail');

//Science page
Route::post('app-setting/science-page','Api\AppSetting\SciencePageController@getSciencePageData');

//UserToken route
Route::post('app-setting/save-token','Api\AppSetting\UserTokenController@saveToken');
Route::post('app-setting/notifyme','Api\AppSetting\UserTokenController@notifyMe');
Route::post('app-setting/reminder-me','Api\AppSetting\UserTokenController@remindMe');
Route::get('app-setting/send-notification','Api\AppSetting\UserTokenController@sendNotification');
Route::post('app-setting/get-currency','Api\AppSetting\UserTokenController@getCurrency');
Route::post('app-setting/change-currency','Api\AppSetting\UserTokenController@changeCurrency');


//Product details route
Route::post('app-setting/product/details','Api\AppSetting\ProductDetailController@getProductDetail');
Route::post('app-setting/product/scan','Api\AppSetting\ProductDetailController@scanProductDetail');

//WebHook route
Route::post('webhook/collection/create','Api\WebHook\WebHookController@createCollection');
Route::post('webhook/collection/update','Api\WebHook\WebHookController@updateCollection');
Route::post('webhook/collection/delete','Api\WebHook\WebHookController@deleteCollection');
Route::post('webhook/product/create','Api\WebHook\WebHookController@productCreate');
Route::post('webhook/product/update','Api\WebHook\WebHookController@productUpdate');
Route::post('webhook/product/delete','Api\WebHook\WebHookController@productDelete');

Route::post('webhook/customers/create','Api\WebHook\WebHookController@customerCreate');
Route::post('webhook/customers/update','Api\WebHook\WebHookController@customerUpdate');

//Playstore redirect route
Route::get('app-setting/playstore/redirect/{code?}','Api\AppSetting\PlayStoreController@playStore');

//Customer route
Route::post('app-setting/customer/create','Api\AppSetting\RegisterController@createCustomer');

//Cart api route
Route::post('app-setting/cart/add','Api\AppSetting\CartController@AddToCart');
Route::post('app-setting/cart/all','Api\AppSetting\CartController@getAllCartProduct');
Route::post('app-setting/cart/delete','Api\AppSetting\CartController@deleteCartProduct');
Route::post('app-setting/cart/update/quantity','Api\AppSetting\CartController@quantityChange');

//Manage alert
Route::post('app-setting/alert/all','Api\AppSetting\ManageAlertController@getAllManageAlert');
Route::post('app-setting/alert/remove','Api\AppSetting\ManageAlertController@removeAlert');

//Wishlist api
Route::post('app-setting/wishlist/add','Api\AppSetting\WishlistController@saveWishlist');
Route::post('app-setting/wishlist/all','Api\AppSetting\WishlistController@getWishlistItem');

// Checkout api routes
Route::post('app-setting/create/checkout','Api\AppSetting\CheckoutController@createCheckout');
Route::get('app-setting/cart/check-item','Api\AppSetting\CheckoutController@checkCompletedCheckout');

//Customer route
Route::post('app-setting/customer/getCustomer','Api\AppSetting\CustomerController@getCustomer');
Route::post('app-setting/customer/address','Api\AppSetting\CustomerController@getCustomerAllAddress');
Route::post('app-setting/customer/address/details','Api\AppSetting\CustomerController@getAddressById');
Route::post('app-setting/customer/address/delete','Api\AppSetting\CustomerController@deleteAddress');
Route::post('app-setting/customer/address/update','Api\AppSetting\CustomerController@updateAddress');

Route::get('app-setting/customer/pagination','Api\AppSetting\CustomerController@pagination');
Route::get('app-setting/customer/update-level','Api\AppSetting\CustomerController@updateCustomerLevel');


//Order route
Route::post('app-setting/customer/orders','Api\AppSetting\OrderController@getCustomerOrder');

//Challenge route
Route::post('app-setting/challenge/section','Api\AppSetting\ChallengeController@getSection');
Route::post('app-setting/challenge/section-challenge','Api\AppSetting\ChallengeController@getAllSectionChallenge');
Route::post('app-setting/challenge/get-challenge','Api\AppSetting\ChallengeController@getChallenge');
Route::post('app-setting/challenge/get-content','Api\AppSetting\ChallengeController@getContent');
Route::post('app-setting/challenge/get-challenge-content','Api\AppSetting\ChallengeController@getChallengeContent');
Route::post('app-setting/challenge/get-final-data','Api\AppSetting\ChallengeController@getFinalData');
Route::post('app-setting/challenge/get-badge','Api\AppSetting\ChallengeController@getBadge');
Route::post('app-setting/challenge/active-challenge','Api\AppSetting\ChallengeController@getActiveChallenge');
Route::post('app-setting/challenge/save-challenge','Api\AppSetting\ChallengeController@saveChallenge');
Route::post('app-setting/challenge/save-complete-challenge','Api\AppSetting\ChallengeController@saveCompleteChallenge');
Route::post('app-setting/challenge/get-save-challenge','Api\AppSetting\ChallengeController@getSavedChallenge');
Route::post('app-setting/challenge/get-complete-challenge','Api\AppSetting\ChallengeController@getCompleteChallenge');

//Milestone route
Route::post('app-setting/milestone','Api\AppSetting\MilestoneController@getMilestone');
Route::post('app-setting/customer-milestone','Api\AppSetting\MilestoneController@getCustomerMilestone');
Route::post('app-setting/currency-milestone','Api\AppSetting\MilestoneController@getCurrencyMilestone');




//Social login route
Route::post('app-setting/customer/social-signin','Api\AppSetting\RegisterController@signInWithSocial');
Route::post('app-setting/customer/social-signup','Api\AppSetting\RegisterController@signUpWithSocial');

//Currency list api
Route::get('app-setting/currency-list','Api\AppSetting\CurrencyChangeController@getCurrencyCodeList');

//exchange rate api cron
Route::get('app-setting/update-currency-rate','Api\AppSetting\CurrencyChangeController@currencyRate');


//customer sync api cron
Route::get('app-setting/sync-customer','Api\AppSetting\CustomerController@pagination');

//get order no by toke
Route::post('app-setting/get-order-no','Api\AppSetting\CheckoutController@getOrderNumberByToken');

//Analytics tutorial route
Route::post('app-setting/skip-count','Api\AppSetting\AnalyticController@checkSkipStep');
Route::post('app-setting/menu-click-count','Api\AppSetting\AnalyticController@checkMenuClickCount');
Route::post('app-setting/view-count','Api\AppSetting\AnalyticController@checkViewCount');
Route::post('app-setting/sent-notification-count','Api\AppSetting\AnalyticController@sentNotificationCount');
Route::post('app-setting/product-detail-count','Api\AppSetting\AnalyticController@productDetailCount');
Route::post('app-setting/faq-count','Api\AppSetting\AnalyticController@faqOpenQuestionCount');
Route::post('app-setting/collection-view-count','Api\AppSetting\AnalyticController@checkCollectionViewCount');
Route::post('app-setting/checkout-step-count','Api\AppSetting\AnalyticController@checkoutStepCount');
Route::post('app-setting/device-order-count','Api\AppSetting\AnalyticController@deviceOrderCount');
Route::post('app-setting/explore-page-count','Api\AppSetting\AnalyticController@explorePageCount');
Route::post('app-setting/product-view-count','Api\AppSetting\AnalyticController@checkProductViewCount');

//clear config
Route::get('app-setting/clear/config',function(){
    Artisan::call('config:clear');
});


