<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});

Auth::routes([
    'register' => false
]);

Route::get('/home', 'HomeController@index')->name('home');


Route::group(['middleware' => ['auth'], 'prefix' => 'admin'], function () {

    //dashboard route
    Route::get('dashboard', 'Admin\AppSetting\Dashboard\DashboardController@index')->name('appsetting.dashboard');
    Route::get('app-setting/dashboard/search-term', 'Admin\AppSetting\Dashboard\DashboardController@getAllSearchTerm')->name('appsetting.dashboard.search');
    Route::get('app-setting/dashboard/export', 'Admin\AppSetting\Dashboard\DashboardController@export')->name('appsetting.dashboard.export');
    Route::get('app-setting/dashboard/export-currency', 'Admin\AppSetting\Dashboard\DashboardController@exportCurrency')->name('appsetting.dashboard.export-currency');
    Route::get('app-setting/dashboard/export-milestone', 'Admin\AppSetting\Dashboard\DashboardController@exportMilestone')->name('appsetting.dashboard.export-milestone');
    Route::get('app-setting/dashboard/export-scan-product', 'Admin\AppSetting\Dashboard\DashboardController@exportScanProduct')->name('appsetting.dashboard.export-scan-product');
    Route::post('app-setting/dashboard/product-detail', 'Admin\AppSetting\Dashboard\DashboardController@productdetail')->name('appsetting.dashboard.product-detail');

    //Home-Page route    
    // Route::get('app-setting/home-page', 'Admin\AppSetting\HomePageController@add')->name('appsetting.home-page');
    Route::get('app-setting/home-page',['middleware' => ['permission:homepagebanner-read'], 'uses' => 'Admin\AppSetting\HomePageController@add'])->name('appsetting.home-page');
    Route::get('app-setting/home-page/all', 'Admin\AppSetting\HomePageController@getHomePageData')->name('appsetting.home-page.getHomePageData');
    Route::post('app-setting/home-page/normal-collection/upload-image', 'Admin\AppSetting\HomePageController@uploadImage')->name('appsetting.home-page.normal-collection.upload');
    Route::post('app-setting/home-page/collection-goal/upload-image', 'Admin\AppSetting\HomePageController@uploadGoalImage')->name('appsetting.home-page.collection-goal.upload');
    Route::post('app-setting/home-page/normal-collection/save-normal-collection', 'Admin\AppSetting\HomePageController@saveNormalCollection')->name('appsetting.home-page.normal-collection.save');
    Route::post('app-setting/home-page/normal-collection/save-collection-goal', 'Admin\AppSetting\HomePageController@saveCollectionGoal')->name('appsetting.home-page.collection-goal.save');
    Route::post('app-setting/home-page/remove-collection-goal', 'Admin\AppSetting\HomePageController@removeGoalCollection')->name('appsetting.home-page.goal-collection.remove');
    Route::post('app-setting/home-page/remove-image', 'Admin\AppSetting\HomePageController@removeImage')->name('appsetting.home-page.remove-image');
    Route::post('app-setting/home-page/remove-collection-goal-image', 'Admin\AppSetting\HomePageController@removeCollectionGoalImage')->name('appsetting.home-page.remove-goal-image');
    Route::post('app-setting/home-page/link/normal-collection', 'Admin\AppSetting\HomePageController@linkNormalCollection')->name('appsetting.home-page.link-normal-collection');
    Route::post('app-setting/home-page/link/collection-goal', 'Admin\AppSetting\HomePageController@linkCollectionGoal')->name('appsetting.home-page.link-collection-goal');
    Route::post('app-setting/home-page/unlink-collection', 'Admin\AppSetting\HomePageController@UnlinkCollection')->name('appsetting.home-page.UnlinkCollection');
    Route::get('app-setting/home-page/getAllCollection', 'Admin\AppSetting\HomePageController@getAllCollection')->name('appsetting.home-page.getAllCollection');
    Route::get('app-setting/home-page/getAllChallenge', 'Admin\AppSetting\HomePageController@getAllChallenge')->name('appsetting.home-page.getAllChallenge');
    Route::get('app-setting/home-page/getAllMenu', 'Admin\AppSetting\HomePageController@getAllMenu')->name('appsetting.home-page.getAllMenu');

    // Banner Section Route
    Route::post('app-setting/home-page/banner/save-banner', 'Admin\AppSetting\HomePageController@saveBanner')->name('appsetting.home-page.banner.save');
    Route::post('app-setting/home-page/banner/upload-image', 'Admin\AppSetting\HomePageController@uploadBannerImage')->name('appsetting.home-page.banner.upload');
    Route::post('app-setting/home-page/banner/cover-image', 'Admin\AppSetting\HomePageController@uploadCoverImage')->name('appsetting.home-page.banner.cover');
    Route::post('app-setting/home-page/remove-banner', 'Admin\AppSetting\HomePageController@removeBanner')->name('appsetting.home-page.banner.remove');
    Route::post('app-setting/home-page/remove-cover-banner', 'Admin\AppSetting\HomePageController@removeCoverBannerImage')->name('appsetting.home-page.banner-cover.remove');

    //Announcement Bar route 
    // Route::get('app-setting/announcement-bar', 'Admin\AppSetting\AnnouncementBarController@index')->name('appsetting.announcement-bar');
    Route::get('app-setting/announcement-bar', ['middleware' => ['permission:announcement_bar-read'], 'uses' =>'Admin\AppSetting\AnnouncementBarController@index'])->name('appsetting.announcement-bar');
    Route::get('app-setting/announcement-bar/all', 'Admin\AppSetting\AnnouncementBarController@getAnnouncementBar')->name('appsetting.announcement-bar.all');
    Route::get('app-setting/announcement-bar/add', 'Admin\AppSetting\AnnouncementBarController@add')->name('appsetting.announcement-bar.add');
    Route::post('app-setting/announcement-bar/store', 'Admin\AppSetting\AnnouncementBarController@store')->name('appsetting.announcement-bar.store');
    Route::get('app-setting/announcement-bar/edit/{id}', 'Admin\AppSetting\AnnouncementBarController@edit')->name('appsetting.announcement-bar.edit');
    Route::post('app-setting/announcement-bar/update', 'Admin\AppSetting\AnnouncementBarController@update')->name('appsetting.announcement-bar.update');
    Route::post('app-setting/announcement-bar/delete', 'Admin\AppSetting\AnnouncementBarController@delete')->name('appsetting.announcement-bar.delete');

    //Dynamic Menu route
    // Route::get('app-setting/menu', 'Admin\AppSetting\Menu\MenuController@index')->name('appsetting.menu.index');
    Route::get('app-setting/menu',['middleware' => ['permission:menu-read'], 'uses' => 'Admin\AppSetting\Menu\MenuController@index'])->name('appsetting.menu.index');
    Route::get('app-setting/menu/add', 'Admin\AppSetting\Menu\MenuController@add')->name('appsetting.menu.add');
    Route::get('app-setting/menu/edit/{id}', 'Admin\AppSetting\Menu\MenuController@edit')->name('appsetting.menu.edit');
    Route::post('app-setting/menu/store', 'Admin\AppSetting\Menu\MenuController@store')->name('appsetting.menu.store');
    Route::post('app-setting/menu/update', 'Admin\AppSetting\Menu\MenuController@update')->name('appsetting.menu.update');
    Route::get('app-setting/menu/all', 'Admin\AppSetting\Menu\MenuController@getAllMenu')->name('appsetting.menu.all');
    Route::post('app-setting/menu/delete', 'Admin\AppSetting\Menu\MenuController@delete')->name('appsetting.menu.delete');
    Route::post('app-setting/menu/upload-icon', 'Admin\AppSetting\Menu\MenuController@uploadIcon')->name('appsetting.menu.upload-icon');
    Route::post('app-setting/menu/remove-icon', 'Admin\AppSetting\Menu\MenuController@removeIcon')->name('appsetting.menu.remove-icon');

    //App Version route 
    // Route::get('app-setting/app-version', 'Admin\AppSetting\AppVersionController@index')->name('appsetting.app-version');
    Route::get('app-setting/app-version', ['middleware' => ['permission:app_version-read'], 'uses' => 'Admin\AppSetting\AppVersionController@index'])->name('appsetting.app-version');
    Route::post('app-setting/app-version/store', 'Admin\AppSetting\AppVersionController@store')->name('appsetting.app-version.store');
    Route::get('app-setting/app-version/list', 'Admin\AppSetting\AppVersionController@list')->name('appsetting.app-version.list');

    //Flash sale route
    // Route::get('app-setting/flash-sale', 'Admin\AppSetting\FlashSale\FlashSaleController@index')->name('appsetting.flash-sale.index');
    Route::get('app-setting/flash-sale', ['middleware' => ['permission:flash_sale-read'], 'uses'=> 'Admin\AppSetting\FlashSale\FlashSaleController@index'])->name('appsetting.flash-sale.index');
    Route::get('app-setting/flash-sale/all', 'Admin\AppSetting\FlashSale\FlashSaleController@getAllFlashSale')->name('appsetting.flash-sale.all');
    Route::post('app-setting/flash-sale/store', 'Admin\AppSetting\FlashSale\FlashSaleController@store')->name('appsetting.flash-sale.store');
    Route::get('app-setting/flash-sale/add', 'Admin\AppSetting\FlashSale\FlashSaleController@add')->name('appsetting.flash-sale.add');
    Route::get('app-setting/flash-sale/edit/{id}', 'Admin\AppSetting\FlashSale\FlashSaleController@edit')->name('appsetting.flash-sale.edit');
    Route::post('app-setting/flash-sale/delete', 'Admin\AppSetting\FlashSale\FlashSaleController@delete')->name('appsetting.flash-sale.delete');
    Route::get('app-setting/flash-sale/getAllCollection', 'Admin\AppSetting\FlashSale\FlashSaleController@getAllCollection')->name('appsetting.flash-sale.getAllCollection');
    Route::post('app-setting/flash-sale/getCollectionProduct', 'Admin\AppSetting\FlashSale\FlashSaleController@getCollectionProduct')->name('appsetting.flash-sale.getCollectionProduct');
    Route::post('app-setting/flash-sale/addExclusiveProduct', 'Admin\AppSetting\FlashSale\FlashSaleController@addExclusiveProduct')->name('appsetting.flash-sale.addExclusiveProduct');
    Route::get('app-setting/flash-sale/getAllShopifyProduct', 'Admin\AppSetting\FlashSale\FlashSaleController@getAllShopifyProduct')->name('appsetting.flash-sale.getAllShopifyProduct');
    Route::post('app-setting/flash-sale/getFlashSaleProduct', 'Admin\AppSetting\FlashSale\FlashSaleController@getFlashSaleProduct')->name('appsetting.flash-sale.getFlashSaleProduct');
    Route::post('app-setting/flash-sale/updateExclusiveProduct', 'Admin\AppSetting\FlashSale\FlashSaleController@updateExclusiveProduct')->name('appsetting.flash-sale.updateExclusiveProduct');




    // Item List route 
    // Route::get('product/product-list', 'Admin\AppSetting\Product\ProductController@index')->name('product.product-list');
    Route::get('product/product-list', ['middleware' => ['permission:products-read'], 'uses'=> 'Admin\AppSetting\Product\ProductController@index'])->name('product.product-list');
    Route::get('product/getProducts', 'Admin\AppSetting\Product\ProductController@getProducts')->name('product.getProducts');
    Route::get('product/productSync', 'Admin\AppSetting\Product\ProductController@products')->name('product.productSync');
    Route::post('product/delete', 'Admin\Product\ProductController@delete')->name('product.delete');
    Route::get('product/productedit/{id}', 'Admin\AppSetting\Product\ProductController@edit')->name('product.productedit');
    Route::post('product/update_product', 'Admin\AppSetting\Product\ProductController@update_product')->name('product.update_product');
    Route::post('product/manage-status', 'Admin\AppSetting\Product\ProductController@manageStatus')->name('product.manage-status');

    // Product Video route 
    Route::post('product/upload-cover-image', 'Admin\AppSetting\Product\ProductVideoController@uploadProductCoverImage');
    Route::post('product/remove-cover-image', 'Admin\AppSetting\Product\ProductVideoController@removeProductCoverImage');
    Route::post('product/upload-video', 'Admin\AppSetting\Product\ProductVideoController@uploadProductVideo');
    Route::post('product/remove-video', 'Admin\AppSetting\Product\ProductVideoController@removeProductVideo');
    Route::post('product/update-productVideo', 'Admin\AppSetting\Product\ProductVideoController@updateProductVideo');
    Route::post('product/delete-video', 'Admin\AppSetting\Product\ProductVideoController@deleteProductVideo');
    Route::post('product/getAllProductVideos', 'Admin\AppSetting\Product\ProductVideoController@getAllProductVideos');

    // Variant List route 
    Route::post('product/variants', 'Admin\AppSetting\Variant\VariantController@getProductVariants');
    Route::post('product/variants-update', 'Admin\AppSetting\Variant\VariantController@updateVariants');

    // Ingrdients route 
    Route::post('product/ingredients/upload-image', 'Admin\AppSetting\Product\ProductController@uploadIngrientsImage');
    Route::post('product/ingredients/remove-image', 'Admin\AppSetting\Product\ProductController@removeIngrientsImage');
    Route::post('product/ingredients/update-ingredients', 'Admin\AppSetting\Product\ProductController@updateIngredients');
    Route::post('product/ingredients/getAllIngredients', 'Admin\AppSetting\Product\ProductController@getAllIngredients');
    Route::post('product/ingredients/remove-ingrients', 'Admin\AppSetting\Product\ProductController@removeIngrients');

    // Collection List route 
    // Route::get('collection/collection-list', 'Admin\Collection\CollectionController@index')->name('collection.collection-list');
    Route::get('collection/collection-list', ['middleware' => ['permission:collections-read'], 'uses'=>  'Admin\Collection\CollectionController@index'])->name('collection.collection-list');
    Route::get('collection/getCollections', 'Admin\Collection\CollectionController@getCollections')->name('collection.getCollections');
    Route::get('collection/collectionSync', 'Admin\Collection\CollectionController@collectionSync')->name('collection.collectionSync');
    Route::post('collection/delete', 'Admin\Collection\CollectionController@delete')->name('collection.delete');
    Route::get('collection/collectionedit/{id}', 'Admin\Collection\CollectionController@edit')->name('collection.collectionedit');
    Route::post('collection/update_collection', 'Admin\Collection\CollectionController@update_collection')->name('collection.update_collection');

    //Category route 
    // Route::get('app-setting/category', 'Admin\AppSetting\Category\CategoryController@index')->name('appsetting.categoryFAQ');
    Route::get('app-setting/category', ['middleware' => ['permission:categories-read'], 'uses'=> 'Admin\AppSetting\Category\CategoryController@index'])->name('appsetting.categoryFAQ');
    Route::get('app-setting/category/all', 'Admin\AppSetting\Category\CategoryController@getCategory')->name('appsetting.category.all');
    Route::get('app-setting/category/add', 'Admin\AppSetting\Category\CategoryController@add')->name('appsetting.category.add');
    Route::post('app-setting/category/store', 'Admin\AppSetting\Category\CategoryController@store')->name('appsetting.category.store');
    Route::get('app-setting/category/edit/{id}', 'Admin\AppSetting\Category\CategoryController@edit')->name('appsetting.category.edit');
    Route::post('app-setting/category/update', 'Admin\AppSetting\Category\CategoryController@update')->name('appsetting.category.update');
    Route::post('app-setting/category/delete', 'Admin\AppSetting\Category\CategoryController@delete')->name('appsetting.category.delete');

    //Category FAQ route 
    // Route::get('app-setting/categoryFAQ', 'Admin\AppSetting\Category\CategoryFAQController@index')->name('appsetting.categoryFAQ');
    Route::get('app-setting/categoryFAQ', ['middleware' => ['permission:faq-read'], 'uses'=>  'Admin\AppSetting\Category\CategoryFAQController@index'])->name('appsetting.categoryFAQ');
    Route::get('app-setting/categoryFAQ/all', 'Admin\AppSetting\Category\CategoryFAQController@getCategory')->name('appsetting.categoryFAQ.all');
    Route::get('app-setting/categoryFAQ/add', 'Admin\AppSetting\Category\CategoryFAQController@add')->name('appsetting.categoryFAQ.add');
    Route::post('app-setting/categoryFAQ/store', 'Admin\AppSetting\Category\CategoryFAQController@store')->name('appsetting.categoryFAQ.store');
    Route::get('app-setting/categoryFAQ/edit/{id}', 'Admin\AppSetting\Category\CategoryFAQController@edit')->name('appsetting.categoryFAQ.edit');
    Route::post('app-setting/categoryFAQ/update', 'Admin\AppSetting\Category\CategoryFAQController@update')->name('appsetting.categoryFAQ.update');
    Route::post('app-setting/categoryFAQ/delete', 'Admin\AppSetting\Category\CategoryFAQController@delete')->name('appsetting.categoryFAQ.delete');
    Route::get('app-setting/categoryFAQ/category-list', 'Admin\AppSetting\Category\CategoryFAQController@getCategoryData')->name('appsetting.category-list.delete');

    //Email setting
    // Route::get('app-setting/contact-us', 'Admin\AppSetting\ContactUs\ContactUsController@index')->name('appsetting.contact-us');
    Route::get('app-setting/contact-us', ['middleware' => ['permission:email-setting-read'], 'uses'=> 'Admin\AppSetting\ContactUs\ContactUsController@index'])->name('appsetting.contact-us');
    Route::post('app-setting/contact-us/store', 'Admin\AppSetting\ContactUs\ContactUsController@store')->name('appsetting.contact-us.store');
    Route::get('app-setting/contact-us/list', 'Admin\AppSetting\ContactUs\ContactUsController@list')->name('appsetting.contact-us.list');

    //Science Page route
    // Route::get('app-setting/science-page', 'Admin\AppSetting\SciencePage\SciencePageController@index')->name('appsetting.science-page');
    Route::get('app-setting/science-page', ['middleware' => ['permission:science_page-read'], 'uses'=> 'Admin\AppSetting\SciencePage\SciencePageController@index'])->name('appsetting.science-page');
    Route::get('app-setting/science-page/all', 'Admin\AppSetting\SciencePage\SciencePageController@getData')->name('appsetting.science-page.all');
    Route::get('app-setting/science-page/add', 'Admin\AppSetting\SciencePage\SciencePageController@add')->name('appsetting.science-page.add');
    Route::get('app-setting/science-page/edit/{id}', 'Admin\AppSetting\SciencePage\SciencePageController@edit')->name('appsetting.science-page.edit');
    Route::post('app-setting/science-page/update', 'Admin\AppSetting\SciencePage\SciencePageController@update')->name('appsetting.science-page.update');
    Route::post('app-setting/science-page/upload-image', 'Admin\AppSetting\SciencePage\SciencePageController@uploadImage')->name('appsetting.science-page.uploadImage');
    Route::post('app-setting/science-page/store', 'Admin\AppSetting\SciencePage\SciencePageController@store')->name('appsetting.science-page.store');
    Route::post('app-setting/science-page/delete/', 'Admin\AppSetting\SciencePage\SciencePageController@delete')->name('appsetting.science-page.delete');
    Route::post('app-setting/science-page/remove-text/', 'Admin\AppSetting\SciencePage\SciencePageController@removeText')->name('appsetting.science-page.remove-text');
    Route::post('app-setting/science-page/remove-image/', 'Admin\AppSetting\SciencePage\SciencePageController@removeImage')->name('appsetting.science-page.remove-image');
    Route::post('app-setting/science-page/manage-status/', 'Admin\AppSetting\SciencePage\SciencePageController@manageStatus')->name('appsetting.science-page.manage-status');

    //Recommend product route
    // Route::get('app-setting/recommend-product', 'Admin\AppSetting\Recommend\RecommendController@index')->name('appsetting.recommend-product');
    Route::get('app-setting/recommend-product', ['middleware' => ['permission:recommend_product-read'], 'uses'=> 'Admin\AppSetting\Recommend\RecommendController@index'])->name('appsetting.recommend-product');
    Route::get('app-setting/recommend-product/getAllRecommendProduct', 'Admin\AppSetting\Recommend\RecommendController@getAllRecommendProduct')->name('appsetting.recommend-product');
    Route::get('app-setting/recommend-product/add', 'Admin\AppSetting\Recommend\RecommendController@add')->name('appsetting.recommend-product.add');
    Route::get('app-setting/recommend-product/edit/{id}', 'Admin\AppSetting\Recommend\RecommendController@edit')->name('appsetting.recommend-product.edit');
    Route::post('app-setting/recommend-product/store', 'Admin\AppSetting\Recommend\RecommendController@store')->name('appsetting.recommend-product.store');
    Route::post('app-setting/recommend-product/update', 'Admin\AppSetting\Recommend\RecommendController@update')->name('appsetting.recommend-product.update');
    Route::get('app-setting/recommend-product/getAllProduct', 'Admin\AppSetting\Recommend\RecommendController@getAllProduct')->name('appsetting.recommend-product.getAllProduct');
    Route::post('app-setting/recommend-product/remove-content', 'Admin\AppSetting\Recommend\RecommendController@removeContent')->name('appsetting.recommend-product.remove-content');
    Route::post('app-setting/recommend-product/delete', 'Admin\AppSetting\Recommend\RecommendController@delete')->name('appsetting.recommend-product.delete');

    //Review product route
    Route::get('app-setting/review-product', 'Admin\AppSetting\Review\ReviewController@index')->name('appsetting.review-product');
    Route::get('app-setting/recommend-product', ['middleware' => ['permission:recommend_product-read'], 'uses'=> 'Admin\AppSetting\Recommend\RecommendController@index'])->name('appsetting.recommend-product');
    Route::get('app-setting/review-product/getAllReviewProduct', 'Admin\AppSetting\Review\ReviewController@getAllReviewProduct')->name('appsetting.review-product.getAllReviewProduct');
    Route::get('app-setting/review-product/add', 'Admin\AppSetting\Review\ReviewController@add')->name('appsetting.review-product.add');
    Route::get('app-setting/review-product/edit/{id}', 'Admin\AppSetting\Review\ReviewController@edit')->name('appsetting.review-product.edit');
    Route::post('app-setting/review-product/upload-image', 'Admin\AppSetting\Review\ReviewController@uploadImage')->name('appsetting.review-product.upload-image');
    Route::post('app-setting/review-product/store', 'Admin\AppSetting\Review\ReviewController@store')->name('appsetting.review-product.store');
    Route::post('app-setting/review-product/update', 'Admin\AppSetting\Review\ReviewController@update')->name('appsetting.review-product.update');
    Route::post('app-setting/review-product/delete', 'Admin\AppSetting\Review\ReviewController@delete')->name('appsetting.review-product.delete');
    Route::post('app-setting/review-product/remove-content', 'Admin\AppSetting\Review\ReviewController@removeContent')->name('appsetting.review-product.remove-content');
    Route::post('app-setting/review-product/remove-image', 'Admin\AppSetting\Review\ReviewController@removeImage')->name('appsetting.review-product.remove-image');
    Route::post('app-setting/review-product/upload-source', 'Admin\AppSetting\Review\ReviewController@uploadSource')->name('appsetting.review-product.upload-source');
    Route::post('app-setting/review-product/remove-source', 'Admin\AppSetting\Review\ReviewController@removeSource')->name('appsetting.review-product.remove-source');

    //Product Category route
    // Route::get('app-setting/product-category', 'Admin\AppSetting\ProductCategory\ProductCategoryController@index')->name('appsetting.product-category');
    Route::get('app-setting/product-category', ['middleware' => ['permission:product_categories-read'], 'uses'=> 'Admin\AppSetting\ProductCategory\ProductCategoryController@index'])->name('appsetting.product-category');
    Route::get('app-setting/product-category/all', 'Admin\AppSetting\ProductCategory\ProductCategoryController@getCategoryData')->name('appsetting.product-category.all');
    Route::post('app-setting/product-category/upload-image', 'Admin\AppSetting\ProductCategory\ProductCategoryController@uploadImage')->name('appsetting.product-category.uploadImage');
    Route::get('app-setting/product-category/add', 'Admin\AppSetting\ProductCategory\ProductCategoryController@add')->name('appsetting.product-category.add');
    Route::post('app-setting/product-category/store', 'Admin\AppSetting\ProductCategory\ProductCategoryController@store')->name('appsetting.product-category.store');
    Route::get('app-setting/product-category/edit/{id}', 'Admin\AppSetting\ProductCategory\ProductCategoryController@edit')->name('appsetting.product-category.edit');
    Route::post('app-setting/product-category/update', 'Admin\AppSetting\ProductCategory\ProductCategoryController@update')->name('appsetting.product-category.update');
    Route::post('app-setting/product-category/delete', 'Admin\AppSetting\ProductCategory\ProductCategoryController@delete')->name('appsetting.product-category.delete');
    Route::get('app-setting/product-category/products', 'Admin\AppSetting\ProductCategory\ProductCategoryController@getProducts')->name('appsetting.product-category.products');
    Route::post('app-setting/product-category/remove-category', 'Admin\AppSetting\ProductCategory\ProductCategoryController@removeCategory')->name('appsetting.product-category.remove-category');
    Route::post('app-setting/product-category/remove-image', 'Admin\AppSetting\ProductCategory\ProductCategoryController@removeImage')->name('appsetting.product-category.remove-image');
    Route::post('app-setting/product-category/upload-cover-image', 'Admin\AppSetting\ProductCategory\ProductCategoryController@uploadCoverImage')->name('appsetting.product-category.uploadCoverImage');
    Route::post('app-setting/product-category/remove-cover-image', 'Admin\AppSetting\ProductCategory\ProductCategoryController@removeCoverImage')->name('appsetting.product-category.remove-cover-image');
    Route::post('app-setting/product-category/remove-cover-and-image', 'Admin\AppSetting\ProductCategory\ProductCategoryController@removeCoverAndImage')->name('appsetting.product-category.remove-cover-and-image');


    //Notification route
    // Route::get('app-setting/notification', 'Admin\AppSetting\Notification\NotificationController@index')->name('appsetting.notification');
    Route::get('app-setting/notification', ['middleware' => ['permission:notifyme-read'], 'uses'=> 'Admin\AppSetting\Notification\NotificationController@index'])->name('appsetting.notification');
    Route::post('app-setting/notification/delete', 'Admin\AppSetting\Notification\NotificationController@delete')->name('appsetting.notification.delete');
    Route::get('app-setting/notification/getAllNotification', 'Admin\AppSetting\Notification\NotificationController@getAllNotification')->name('appsetting.notification.getAllNotification');

    //Manual Notification route
    // Route::get('app-setting/manual-notification', 'Admin\AppSetting\ManualNotification\ManualNotificationController@index')->name('appsetting.manual-notification');
    Route::get('app-setting/manual-notification', ['middleware' => ['permission:manual_notifications-read'], 'uses'=> 'Admin\AppSetting\ManualNotification\ManualNotificationController@index'])->name('appsetting.manual-notification');
    Route::get('app-setting/manual-notification/add', 'Admin\AppSetting\ManualNotification\ManualNotificationController@add')->name('appsetting.manual-notification.add');
    Route::post('app-setting/manual-notification/store', 'Admin\AppSetting\ManualNotification\ManualNotificationController@store')->name('appsetting.manual-notification.store');
    Route::get('app-setting/manual-notification/edit/{id}', 'Admin\AppSetting\ManualNotification\ManualNotificationController@edit')->name('appsetting.manual-notification.edit');
    Route::post('app-setting/manual-notification/update', 'Admin\AppSetting\ManualNotification\ManualNotificationController@update')->name('appsetting.manual-notification.update');
    Route::post('app-setting/manual-notification/delete', 'Admin\AppSetting\ManualNotification\ManualNotificationController@delete')->name('appsetting.manual-notification.delete');
    Route::post('app-setting/manual-notification/upload-image', 'Admin\AppSetting\ManualNotification\ManualNotificationController@uploadImage')->name('appsetting.manual-notification.upload-image');
    Route::post('app-setting/manual-notification/remove-image', 'Admin\AppSetting\ManualNotification\ManualNotificationController@removeImage')->name('appsetting.manual-notification.remove-image');
    Route::get('app-setting/manual-notification/getAllNotification', 'Admin\AppSetting\ManualNotification\ManualNotificationController@getAllNotification')->name('appsetting.manual-notification.getAllNotification');


    // Customer List route 
    // Route::get('app-setting/customer/customer-list', 'Admin\AppSetting\Customer\CustomerController@index')->name('customer.customer-list');
    Route::get('app-setting/customer/customer-list', ['middleware' => ['permission:customers-read'], 'uses'=> 'Admin\AppSetting\Customer\CustomerController@index'])->name('customer.customer-list');
    Route::get('app-setting/customer/getCustomers', 'Admin\AppSetting\Customer\CustomerController@getCustomers')->name('customer.getCustomers');
    Route::get('app-setting/customer/customerSync', 'Admin\AppSetting\Customer\CustomerController@customerSync')->name('customer.customerSync');
    Route::get('app-setting/customer/edit/{customer_id}', 'Admin\AppSetting\Customer\CustomerController@customerEdit')->name('customer.edit');
    Route::post('app-setting/customer/update', 'Admin\AppSetting\Customer\CustomerController@customerUpdate')->name('customer.update');

    //Challenge Section route /////////////////////////
    // Route::get('app-setting/challenge-section', 'Admin\AppSetting\Challenge\ChallengeSectionController@index')->name('appsetting.challenge-section');
    Route::get('app-setting/challenge-section', ['middleware' => ['permission:challenges-read'], 'uses'=> 'Admin\AppSetting\Challenge\ChallengeSectionController@index'])->name('appsetting.challenge-section');
    Route::get('app-setting/challenge-section/all', 'Admin\AppSetting\Challenge\ChallengeSectionController@getChallenge')->name('appsetting.challenge-section.all');
    Route::get('app-setting/challenge-section/add', 'Admin\AppSetting\Challenge\ChallengeSectionController@add')->name('appsetting.challenge-section.add');
    Route::post('app-setting/challenge-section/store', 'Admin\AppSetting\Challenge\ChallengeSectionController@store')->name('appsetting.challenge-section.store');
    Route::get('app-setting/challenge-section/edit/{id}', 'Admin\AppSetting\Challenge\ChallengeSectionController@edit')->name('appsetting.challenge-section.edit');
    Route::post('app-setting/challenge-section/update', 'Admin\AppSetting\Challenge\ChallengeSectionController@update')->name('appsetting.challenge-section.update');
    Route::post('app-setting/challenge-section/delete', 'Admin\AppSetting\Challenge\ChallengeSectionController@delete')->name('appsetting.challenge-section.delete');
    Route::post('app-setting/challenge-section/upload-image', 'Admin\AppSetting\Challenge\ChallengeSectionController@uploadImage')->name('appsetting.challenge-section.upload-image');
    Route::post('app-setting/challenge-section/remove-image', 'Admin\AppSetting\Challenge\ChallengeSectionController@removeImage')->name('appsetting.challenge-section.remove-image');
    Route::post('app-setting/challenge-section/manage-status', 'Admin\AppSetting\Challenge\ChallengeSectionController@manageStatus')->name('appsetting.challenge-section.manage-status');




    //Challenge route ///////////////////////////////////////
    Route::get('app-setting/challenge/section', 'Admin\AppSetting\Challenge\ChallengeController@getAllChallengeSection')->name('appsetting.challenge.section');
    Route::post('app-setting/challenge/content', 'Admin\AppSetting\Challenge\ChallengeController@getAllContent')->name('appsetting.challenge.content');
    // Route::get('app-setting/challenge', 'Admin\AppSetting\Challenge\ChallengeController@index')->name('appsetting.challenge');
    Route::get('app-setting/challenge', ['middleware' => ['permission:challenge_contents-read'], 'uses'=> 'Admin\AppSetting\Challenge\ChallengeController@index'])->name('appsetting.challenge');
    Route::get('app-setting/challenge/all', 'Admin\AppSetting\Challenge\ChallengeController@getChallenge')->name('appsetting.challenge.all');
    Route::get('app-setting/challenge/add', 'Admin\AppSetting\Challenge\ChallengeController@add')->name('appsetting.challenge.add');
    Route::post('app-setting/challenge/store', 'Admin\AppSetting\Challenge\ChallengeController@store')->name('appsetting.challenge.store');
    Route::get('app-setting/challenge/edit/{id}', 'Admin\AppSetting\Challenge\ChallengeController@edit')->name('appsetting.challenge.edit');
    Route::post('app-setting/challenge/update', 'Admin\AppSetting\Challenge\ChallengeController@update')->name('appsetting.challenge.update');
    Route::post('app-setting/challenge/delete', 'Admin\AppSetting\Challenge\ChallengeController@delete')->name('appsetting.challenge.delete');
    Route::post('app-setting/challenge/upload-cover-image', 'Admin\AppSetting\Challenge\ChallengeController@uploadCoverImage')->name('appsetting.challenge.upload-cover-image');
    Route::post('app-setting/challenge/remove-cover-image', 'Admin\AppSetting\Challenge\ChallengeController@removeCoverImage')->name('appsetting.challenge.remove-cover-image');
    Route::post('app-setting/challenge/upload-description-image', 'Admin\AppSetting\Challenge\ChallengeController@uploadDescriptionImage')->name('appsetting.challenge.upload-description-image');
    Route::post('app-setting/challenge/remove-description-image', 'Admin\AppSetting\Challenge\ChallengeController@removeDescriptionImage')->name('appsetting.challenge.remove-description-image');


    Route::post('app-setting/challenge/upload-final-cover-image', 'Admin\AppSetting\Challenge\ChallengeController@uploadFinalCoverImage')->name('appsetting.challenge.upload-final-cover-image');
    Route::post('app-setting/challenge/remove-final-cover-image', 'Admin\AppSetting\Challenge\ChallengeController@removeFinalCoverImage')->name('appsetting.challenge.remove-final-cover-image');
    Route::post('app-setting/challenge/upload-final-url', 'Admin\AppSetting\Challenge\ChallengeController@uploadFinalUrl')->name('appsetting.challenge.upload-final-url');
    Route::post('app-setting/challenge/remove-final-url', 'Admin\AppSetting\Challenge\ChallengeController@removeFinalUrl')->name('appsetting.challenge.remove-final-url');
    Route::post('app-setting/challenge/remove-final-cover-and-url', 'Admin\AppSetting\Challenge\ChallengeController@removeCoverUrl')->name('appsetting.challenge.remove-final-cover-and-url');

    Route::post('app-setting/challenge/upload-badge', 'Admin\AppSetting\Challenge\ChallengeController@uploadBadge')->name('appsetting.challenge.upload-badge');
    Route::post('app-setting/challenge/remove-badge', 'Admin\AppSetting\Challenge\ChallengeController@removeBadge')->name('appsetting.challenge.remove-badge');
    Route::post('app-setting/challenge/remove-duration', 'Admin\AppSetting\Challenge\ChallengeController@removeDuration')->name('appsetting.challenge.remove-duration');
    Route::post('app-setting/challenge/manage-status', 'Admin\AppSetting\Challenge\ChallengeController@manageStatus')->name('appsetting.challenge.manage-status');

    Route::post('app-setting/challenge/upload-content-cover-image', 'Admin\AppSetting\Challenge\ChallengeController@uploadContentCoverImage')->name('appsetting.challenge.upload-content-cover-image');
    Route::post('app-setting/challenge/remove-content-cover-image', 'Admin\AppSetting\Challenge\ChallengeController@removeContentCoverImage')->name('appsetting.challenge.remove-content-cover-image');
    Route::post('app-setting/challenge/upload-content-url', 'Admin\AppSetting\Challenge\ChallengeController@uploadContentUrl')->name('appsetting.challenge.upload-content-url');
    Route::post('app-setting/challenge/remove-content-url', 'Admin\AppSetting\Challenge\ChallengeController@removeContentUrl')->name('appsetting.challenge.remove-content-url');
    Route::post('app-setting/challenge/remove-content-cover-and-url', 'Admin\AppSetting\Challenge\ChallengeController@removeContentCoverUrl')->name('appsetting.challenge.remove-content-cover-and-url');
    Route::post('app-setting/challenge/remove-content', 'Admin\AppSetting\Challenge\ChallengeController@removeContent')->name('appsetting.challenge.remove-content');


    //milestone route
    Route::get('app-setting/milestone/customer', 'Admin\AppSetting\Milestone\MilestoneController@getAllCustomer')->name('appsetting.milestone.customer');
    Route::post('app-setting/milestone/customer-detail', 'Admin\AppSetting\Milestone\MilestoneController@getCustomerDetail')->name('appsetting.milestone.customer-detail');
    Route::get('app-setting/milestone/customer-milestone', 'Admin\AppSetting\Milestone\MilestoneController@getCustomerMilestone')->name('appsetting.milestone.customer-milestone');
    Route::get('app-setting/milestone/all', 'Admin\AppSetting\Milestone\MilestoneController@getMilestone')->name('appsetting.milestone.all');
    // Route::get('app-setting/milestone/add', 'Admin\AppSetting\Milestone\MilestoneController@add')->name('appsetting.milestone.add');
    Route::get('app-setting/milestone/add', ['middleware' => ['permission:milestones-read'], 'uses'=> 'Admin\AppSetting\Milestone\MilestoneController@add'])->name('appsetting.milestone.add');
    Route::post('app-setting/milestone/store', 'Admin\AppSetting\Milestone\MilestoneController@store')->name('appsetting.milestone.store');
    Route::post('app-setting/milestone/store-customer-milestone', 'Admin\AppSetting\Milestone\MilestoneController@storeCustomerMilestone')->name('appsetting.milestone.update');
    Route::post('app-setting/milestone/remove-customer-milestone', 'Admin\AppSetting\Milestone\MilestoneController@deleteCustomerMilestone')->name('appsetting.milestone.delete');
    Route::post('app-setting/milestone/remove-prize-english', 'Admin\AppSetting\Milestone\MilestoneController@removePrizeEnglish')->name('appsetting.milestone.remove-prize');
    Route::post('app-setting/milestone/remove-prize-arabic', 'Admin\AppSetting\Milestone\MilestoneController@removePrizeArabic')->name('appsetting.milestone.remove-prize');
    Route::get('app-setting/milestone/currency', 'Admin\AppSetting\Milestone\MilestoneController@getCurrency')->name('appsetting.milestone.currency');
    Route::post('app-setting/milestone/currency-detail', 'Admin\AppSetting\Milestone\MilestoneController@getCurrencyDetail')->name('appsetting.milestone.currency-detail');
    Route::post('app-setting/milestone/store-currency-point', 'Admin\AppSetting\Milestone\MilestoneController@storeCurrencyPoint')->name('appsetting.milestone.store-currency-point');
    Route::post('app-setting/milestone/upload-image', 'Admin\AppSetting\Milestone\MilestoneController@uploadImage')->name('appsetting.milestone.upload-image');
    Route::post('app-setting/milestone/remove-milestone-image', 'Admin\AppSetting\Milestone\MilestoneController@removeMilestoneImage')->name('appsetting.milestone.remove-milestone-image');
    Route::post('app-setting/milestone/customer_search', 'Admin\AppSetting\Milestone\MilestoneController@getCustomerBySeacrh')->name('appsetting.milestone.customer_search');
    
    //Management route
     Route::get('app-setting/management', ['middleware' => ['permission:managements-read'], 'uses'=> 'Admin\AppSetting\Management\ManagementController@index'])->name('appsetting.management.index');
     Route::get('app-setting/management/add', 'Admin\AppSetting\Management\ManagementController@add')->name('appsetting.management.add');
     Route::get('app-setting/management/edit/{id}', 'Admin\AppSetting\Management\ManagementController@edit')->name('appsetting.management.edit');
     Route::post('app-setting/management/store', 'Admin\AppSetting\Management\ManagementController@store')->name('appsetting.management.store');
     Route::post('app-setting/management/update', 'Admin\AppSetting\Management\ManagementController@update')->name('appsetting.management.update');
     Route::get('app-setting/management/all', 'Admin\AppSetting\Management\ManagementController@getAllUser')->name('appsetting.management.all');
     Route::post('app-setting/management/delete', 'Admin\AppSetting\Management\ManagementController@delete')->name('appsetting.management.delete');
     Route::post('app-setting/management/manage-status', 'Admin\AppSetting\Management\ManagementController@manageStatus')->name('appsetting.management.delete');
     Route::get('app-setting/management/history', 'Admin\AppSetting\Management\ManagementController@getHistory')->name('appsetting.management.history');
     Route::get('app-setting/management/export', 'Admin\appsetting\Management\ManagementController@export')->name('appsetting.management.export');
         Route::get('app-setting/dashboard/export-remind-sent', 'Admin\AppSetting\Dashboard\DashboardController@remindSentExport')->name('appsetting.dashboard.export-remind');
    Route::get('app-setting/dashboard/export-intro-count', 'Admin\AppSetting\Dashboard\DashboardController@exportIntro')->name('appsetting.dashboard.export-intro');
    Route::get('app-setting/dashboard/export-menu-list', 'Admin\AppSetting\Dashboard\DashboardController@exportMenuList')->name('appsetting.dashboard.export-menu');
    Route::get('app-setting/dashboard/export-view-product', 'Admin\AppSetting\Dashboard\DashboardController@exportViewProduct')->name('appsetting.dashboard.export-view-product');
    Route::get('app-setting/dashboard/export-view-collection', 'Admin\AppSetting\Dashboard\DashboardController@exportViewCollection')->name('appsetting.dashboard.export-view-collection');
    Route::get('app-setting/dashboard/export-product-detail', 'Admin\AppSetting\Dashboard\DashboardController@exportProductDetail')->name('appsetting.dashboard.export-product-detail');
     Route::get('app-setting/dashboard/export-search-term', 'Admin\AppSetting\Dashboard\DashboardController@exportSearchTerm')->name('appsetting.dashboard.export-search-term');
     Route::get('app-setting/dashboard/export-notification-sent', 'Admin\AppSetting\Dashboard\DashboardController@exportNotificationSent')->name('appsetting.dashboard.export-notification-sent');
      Route::get('app-setting/dashboard/search-term', 'Admin\AppSetting\Dashboard\DashboardController@getAllSearchTerm')->name('appsetting.dashboard.search');
    Route::get('app-setting/dashboard/scan-product', 'Admin\AppSetting\Dashboard\DashboardController@getScanProduct')->name('appsetting.dashboard.scan-product');
    Route::get('app-setting/dashboard/remind-notify-count', 'Admin\AppSetting\Dashboard\DashboardController@getRemindNotifyCount')->name('appsetting.dashboard.remind-notify-count');
    Route::get('app-setting/dashboard/faq-count', 'Admin\AppSetting\Dashboard\DashboardController@getFaq')->name('appsetting.dashboard.faq-count');
    Route::get('app-setting/dashboard/currency-count', 'Admin\AppSetting\Dashboard\DashboardController@getCurrencyCount')->name('appsetting.dashboard.currency-count');


    Route::get('app-setting/dashboard/export-faq', 'Admin\AppSetting\Dashboard\DashboardController@exportFaq')->name('appsetting.dashboard.export-faq');
    Route::get('app-setting/dashboard/export-remove-cart', 'Admin\AppSetting\Dashboard\DashboardController@exportRemoveCart')->name('appsetting.dashboard.export-remove-cart');
    Route::get('app-setting/dashboard/remove-cart-count', 'Admin\AppSetting\Dashboard\DashboardController@getRemoveCartCount')->name('appsetting.dashboard.remove-cart-count');
    
    Route::get('app-setting/dashboard/alert-notify-count', 'Admin\AppSetting\Dashboard\DashboardController@getAlertNotifyCount')->name('appsetting.dashboard.alert-notify-count');
    Route::get('app-setting/dashboard/view-collection', 'Admin\AppSetting\Dashboard\DashboardController@getViewCollection')->name('appsetting.dashboard.view-collection');
    // Customer List route 
    Route::get('app-setting/customer/export', 'Admin\AppSetting\Customer\CustomerController@customerExport')->name('customer.customer-export');

 Route::get('app-setting/dashboard/milestone-count', 'Admin\AppSetting\Dashboard\DashboardController@getMilestoneCount')->name('appsetting.dashboard.milestone-count');
    Route::get('app-setting/dashboard/view-product', 'Admin\AppSetting\Dashboard\DashboardController@getViewProduct')->name('appsetting.dashboard.view-product');
    Route::get('app-setting/dashboard/export-addtocart-count', 'Admin\AppSetting\Dashboard\DashboardController@exportAddToCart')->name('appsetting.dashboard.export-addtocart-count');
    Route::get('app-setting/dashboard/export-order-count', 'Admin\AppSetting\Dashboard\DashboardController@orderFromExport')->name('appsetting.dashboard.export-order');

    Route::get('app-setting/dashboard/export-checkout-count', 'Admin\AppSetting\Dashboard\DashboardController@exportCheckoutStep')->name('appsetting.dashboard.export-checkout');
    Route::get('app-setting/dashboard/manual-notification-count', 'Admin\AppSetting\Dashboard\DashboardController@getManualNotificationCount')->name('appsetting.dashboard.manual-notification-count');
    Route::get('app-setting/dashboard/date', 'Admin\AppSetting\Dashboard\DashboardController@dateChange')->name('appsetting.dashboard.date');






});
